is_orderable

Function is_orderable 

pub fn is_orderable(hops: &[RelationHop]) -> bool
Whether every hop is to-one. Ordering through a to-many hop is not expressible as a scalar correlated subquery, so generated asc()/ desc() accessors are gated on this (previously enforced by simply not emitting those methods past a to-many hop).